Functions
=========

.. automodule:: jmstate.functions
   :no-members:
   :no-undoc-members:
   :no-index:

.. autosummary::
   :toctree: generated/
   :recursive:

   Exponential
   Gompertz
   LogNormal
   Net
   Weibull
   clock_forward
   clock_reset
   gamma_plus_b
   gamma_x_plus_b
   identity
   linear